obb

Function obb 

pub fn obb(pts: &[Point<f64>]) -> (Isometry<f64>, Cuboid)
Computes an oriented bounding box for the given set of points.

The returned OBB is not guaranteed to be the smallest enclosing OBB. Though it should be a pretty good on for most purposes.